@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.10.0;
 
-our $VERSION = '1.766';
+our $VERSION = '1.769';
 use Exporter 'import';
 our @EXPORT_OK = qw( choose );
 
@@ -315,7 +315,7 @@ sub __choose {
     if ( $self->{mouse} ) {
         require Term::Choose::Opt::Mouse;
     }
-    if ( $^O eq "MSWin32" ) {
+    if ( $^O eq 'MSWin32' ) {
         print $opt->{codepage_mapping} ? "\e(K" : "\e(U";
     }
     $self->__copy_orig_list( $orig_list_ref );
@@ -729,10 +729,7 @@ sub __beep {
 
 sub __prepare_info_and_prompt_lines {
     my ( $self ) = @_;
-    my $info_w = $self->{term_width};
-    if ( $^O ne 'MSWin32' && $^O ne 'cygwin' ) {
-        $info_w += WIDTH_CURSOR;
-    }
+    my $info_w = $self->{term_width} + EXTRA_W;
     if ( $self->{max_width} && $info_w > $self->{max_width} ) { ##
         $info_w = $self->{max_width};
     }
@@ -745,8 +742,9 @@ sub __prepare_info_and_prompt_lines {
         my $subseq   = $self->{tabs_info}[1] // 0;
         my $r_margin = $self->{tabs_info}[2] // 0;
         push @tmp_prompt, line_fold(
-            $self->{info}, $info_w - $r_margin,
-            { init_tab => ' ' x $init, subseq_tab => ' ' x $subseq, color => $self->{color}, join => 0 }
+            $self->{info},
+            { width => $info_w - $r_margin, init_tab => ' ' x $init, subseq_tab => ' ' x $subseq,
+              color => $self->{color}, join => 0 }
         );
     }
     if ( length $self->{prompt} ) {
@@ -754,8 +752,9 @@ sub __prepare_info_and_prompt_lines {
         my $subseq   = $self->{tabs_prompt}[1] // 0;
         my $r_margin = $self->{tabs_prompt}[2] // 0;
         push @tmp_prompt, line_fold(
-            $self->{prompt}, $info_w - $r_margin,
-            { init_tab => ' ' x $init, subseq_tab => ' ' x $subseq, color => $self->{color}, join => 0 }
+            $self->{prompt},
+            { width => $info_w - $r_margin, init_tab => ' ' x $init, subseq_tab => ' ' x $subseq,
+              color => $self->{color}, join => 0 }
         );
     }
     if ( length $self->{search_info} ) {
@@ -1059,11 +1058,12 @@ sub __avail_screen_size {
     if ( $self->{margin_right} ) {
         $self->{avail_width} -= $self->{margin_right};
     }
-    if ( $self->{margin_right} || ( $self->{col_width} > $self->{avail_width} && $^O ne 'MSWin32' && $^O ne 'cygwin' ) ) {
-        $self->{avail_width} += WIDTH_CURSOR;
-        # + WIDTH_CURSOR: use also the last terminal column if there is only one item-column;
-        #                 with only one item-column the output doesn't get messed up if an item
-        #                 reaches the right edge of the terminal on a non-MSWin32-OS
+
+    if ( $self->{margin_right} || ( $self->{col_width} > $self->{avail_width} ) ) {
+        $self->{avail_width} += EXTRA_W;
+        # + EXTRA_W: use also the last terminal column if there is only one item-column;
+        #            with only one item-column the output doesn't get messed up if an item
+        #            reaches the right edge of the terminal on a non-MSWin32-OS (EXTRA_W is 0 if OS is MSWin32)
     }
     if ( $self->{max_width} && $self->{avail_width} > $self->{max_width} ) {
         $self->{avail_width} = $self->{max_width};
@@ -1280,7 +1280,7 @@ Term::Choose - Choose items from a list interactively.
 
 =head1 VERSION
 
-Version 1.766
+Version 1.769
 
 =cut
 
@@ -1680,7 +1680,7 @@ I<margin> expects a reference to an array with four elements in the following or
 
 - right margin (number of terminal columns)
 
-- botton margin (number of terminal lines)
+- bottom margin (number of terminal lines)
 
 - left margin (number of terminal columns)
 
@@ -1925,8 +1925,10 @@ It is required a terminal that uses a monospaced font which supports the printed
 
 =head2 Ambiguous width characters
 
-By default ambiguous width characters are treated as half width. If the environment variable C<TC_AMBIGUOUS_WIDE> is set
-to a true value, ambiguous width characters are treated as full width.
+By default ambiguous width characters are treated as half width. If the environment variable
+C<TC_AMBIGUOUS_WIDTH_IS_WIDE> is set to a true value, ambiguous width characters are treated as full width.
+
+The support for the old variable name C<TC_AMBIGUOUS_WIDE> will be removed.
 
 =head2 Escape sequences
 
@@ -1938,7 +1940,7 @@ The escape sequences to enable the I<mouse> mode are always hardcoded.
 =head2 Other environment variables
 
 If the environment variable C<TC_RESET_AUTO_UP> existed when calling C<choose>: C<TC_RESET_AUTO_UP> is set to C<0> if
-the C<LINE_FEED>/C<CARRIAGE_RETURN> key was the only key pressed and C<TC_RESET_AUTO_UP> is set ot C<1> if other keys
+the C<LINE_FEED>/C<CARRIAGE_RETURN> key was the only key pressed and C<TC_RESET_AUTO_UP> is set to C<1> if other keys
 than C<LINE_FEED>/C<CARRIAGE_RETURN> were also pressed.
 
 =head2 MSWin32
@@ -1965,7 +1967,7 @@ L<stackoverflow|http://stackoverflow.com> for the help.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2012-2024 Matthäus Kiem.
+Copyright (C) 2012-2025 Matthäus Kiem.
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl 5.10.0. For
 details, see the full text of the licenses in the file LICENSE.
