@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.10.0;
 
-our $VERSION = '1.767';
+our $VERSION = '1.769';
 
 use Exporter qw( import );
 
@@ -18,7 +18,7 @@ our @EXPORT_OK = qw(
     VK_INSERT VK_DELETE VK_HOME VK_END VK_PAGE_UP VK_PAGE_DOWN
     VK_F1 VK_F2 VK_F3 VK_F4
     ROW COL
-    WIDTH_CURSOR TERM_READKEY
+    WIDTH_CURSOR EXTRA_W TERM_READKEY
     PH SGR_ES
 );
 
@@ -31,6 +31,8 @@ use constant TERM_READKEY => eval { require Term::ReadKey; 1 };
 
 use constant WIDTH_CURSOR => 1;
 
+use constant EXTRA_W => $^O eq 'MSWin32' || $^O eq 'cygwin' ? 0 : WIDTH_CURSOR;
+
 use constant {
     PH     => "\x{feff}",       # zero width placeholder character
     SGR_ES => '\e\[[\d;]*m',
